@@ -40,7 +40,6 @@ mod hoist_props;
 mod if_return;
 mod iife;
 mod inline;
-mod join_vars;
 mod loops;
 mod ops;
 mod sequences;
@@ -337,12 +336,6 @@ where
             stmts.visit_with(&mut AssertValid);
         }
 
-        self.join_vars(stmts);
-
-        if cfg!(debug_assertions) {
-            stmts.visit_with(&mut AssertValid);
-        }
-
         self.make_sequences(stmts);
 
         if cfg!(debug_assertions) {
